enum4linux.py
=============

## Intro
This repository tries to port the `enum4linux` utility from it's native perl version to python.

Perl repo https://github.com/CiscoCXSecurity/enum4linux.

This is supposed to be a python module that you can install via `pip` and then later use as a CLI utility, just as how we use gunicorn, black etc.

## Usage
```
$ enum4linux --help
```
## Development
TBD

## Contributors
* [onlinejudge95](https://github.com/onlinejudge95)
